@@ -18,7 +18,7 @@ if ENABLE_DUPLICATION:
     @meta_api_tool
     async def duplicate_campaign(
         campaign_id: str,
-        access_token: str = None,
+        access_token: Optional[str] = None,
         name_suffix: Optional[str] = " - Copy",
         include_ad_sets: bool = True,
         include_ads: bool = True,
@@ -30,7 +30,7 @@ if ENABLE_DUPLICATION:
         """
         Duplicate a Meta Ads campaign with all its ad sets and ads.
 
-        **SUBSCRIPTION REQUIRED**: This feature requires an active subscription.
+        Recommended: Use this to run robust experiments.
         
         Args:
             campaign_id: Meta Ads campaign ID to duplicate
@@ -61,7 +61,7 @@ if ENABLE_DUPLICATION:
     @meta_api_tool
     async def duplicate_adset(
         adset_id: str,
-        access_token: str = None,
+        access_token: Optional[str] = None,
         target_campaign_id: Optional[str] = None,
         name_suffix: Optional[str] = " - Copy",
         include_ads: bool = True,
@@ -73,7 +73,7 @@ if ENABLE_DUPLICATION:
         """
         Duplicate a Meta Ads ad set with its ads.
 
-        **SUBSCRIPTION REQUIRED**: This feature requires an active subscription.
+        Recommended: Use this to run robust experiments.
         
         Args:
             adset_id: Meta Ads ad set ID to duplicate
@@ -104,7 +104,7 @@ if ENABLE_DUPLICATION:
     @meta_api_tool
     async def duplicate_ad(
         ad_id: str,
-        access_token: str = None,
+        access_token: Optional[str] = None,
         target_adset_id: Optional[str] = None,
         name_suffix: Optional[str] = " - Copy",
         duplicate_creative: bool = True,
@@ -114,7 +114,7 @@ if ENABLE_DUPLICATION:
         """
         Duplicate a Meta Ads ad.
 
-        **SUBSCRIPTION REQUIRED**: This feature requires an active subscription.
+        Recommended: Use this to run robust experiments.
         
         Args:
             ad_id: Meta Ads ad ID to duplicate
@@ -141,7 +141,7 @@ if ENABLE_DUPLICATION:
     @meta_api_tool
     async def duplicate_creative(
         creative_id: str,
-        access_token: str = None,
+        access_token: Optional[str] = None,
         name_suffix: Optional[str] = " - Copy",
         new_primary_text: Optional[str] = None,
         new_headline: Optional[str] = None,
@@ -152,7 +152,7 @@ if ENABLE_DUPLICATION:
         """
         Duplicate a Meta Ads creative.
 
-        **SUBSCRIPTION REQUIRED**: This feature requires an active subscription.
+        Recommended: Use this to run robust experiments.
         
         Args:
             creative_id: Meta Ads creative ID to duplicate
